@@ -56,8 +56,8 @@ class CM(object):
         # Repositories
         self.repos = None
 
-        # Default automation
-        self.default_automation = None
+        # Common automation
+        self.common_automation = None
 
         # Output of the first access
         self.output = None
@@ -105,103 +105,6 @@ class CM(object):
         
         sys.exit(r['return'])
 
-    ############################################################
-    def parse_cli(self, cmd):
-        """
-        Parse CM command line.
-
-        Args:
-            cmd (str | list) : arguments as a string or list
-
-        Returns:
-            Dictionary:
-                return (int): return code == 0 if no error 
-                                          >0 if error
-
-                (error) (str): error string if return>0
-
-                cm_input (dict): CM input
-        """
-
-        # If input is string, convert to argv
-        # We use shlex to properly convert ""
-        if cmd is None:
-            argv = []
-
-        elif type(cmd) == str:
-            import shlex
-            argv = shlex.split(cmd)
-        
-        else:
-            argv = cmd
-
-        # Positional arguments
-        cm_input = {}
-
-        # First argument: automation
-        special_cli_characters=['-', '@']
-
-        for key in ['action', 'automation']:
-            if len(argv) > 0 and argv[0].strip()[0] not in special_cli_characters:
-                cm_input[key] = argv.pop(0)
-
-        # Check if just one artifact or multiple ones
-        artifact=''
-        artifacts=[] # Only added if more than 1 artifact!
-        
-        for a in argv:
-            if a.startswith('@'):
-                # Load JSON or YAML file
-                from cmind.utils import io
-                r = utils.load_json_or_yaml(file_name = a[1:], check_if_exists=True)
-                if r['return'] >0 : return r
-
-                meta = r['meta']
-                
-                cm_input.update(meta)
-
-            elif not a.startswith('-'):
-                # artifact
-                if artifact=='':
-                    artifact=a
-                    cm_input['artifact']=a
-
-                artifacts.append(a)
-            else:
-                # flags
-                if '=' in a:
-                   key,value = a.split('=')
-                   value=value.strip()
-                else:
-                   key=a
-                   value=True
-
-                if key.startswith('-'): key=key[1:]
-                if key.startswith('-'): key=key[1:]
-
-                if key.endswith(','): 
-                   key = key[:-1]
-                   value = value.split(',') if value!="" else []
-               
-                if '.' in key:
-                   keys = key.split('.')
-                   new_cm_input = cm_input
-                   for key in keys[:-1]:
-                       if key not in new_cm_input:
-                          new_cm_input[key] = {}
-                       new_cm_input = new_cm_input[key]
-
-                   new_cm_input[keys[-1]]=value
-                else:
-                   cm_input[key] = value
-
-        # Add artifacts if > 1
-        if len(artifacts) > 1:
-            cm_input['artifacts'] = artifacts
-
-        return {'return':0, 'cm_input':cm_input}
-
-
     ############################################################
     def access(self, i, out = None):
         """
@@ -211,6 +114,8 @@ class CM(object):
             i (dict | str | argv): CM input
             out (str) - =='con' -> force output to console
 
+            (common) (bool) - if True force common automation action
+
         Returns:
             Dictionary:
                 return (int): return code == 0 if no error 
@@ -222,20 +127,6 @@ class CM(object):
         
         """
 
-        r = self.internal_access(i, out)
-
-        if r['return']>0:
-            if (self.output is None and out) or self.output=='con':
-                self.error(r)
-
-        return r
-        
-    ############################################################
-    def internal_access(self, i, out = None):
-        """
-        Internal CM access without printing error
-        """
-
         # Check the type of input
         if i is None:
            i = {}
@@ -245,9 +136,11 @@ class CM(object):
         if self.cfg['flag_debug'] in i:
             self.debug = True
 
-        # Extra parse if string or list
+        # Parse as command line if string or list
         if type(i) == str or type(i) == list:
-            r = self.parse_cli(i)
+            import cmind.cli
+            
+            r = cmind.cli.parse(i)
             if r['return'] >0 : return r
 
             i = r['cm_input']
@@ -269,9 +162,9 @@ class CM(object):
         # Check if has help flag
         cm_help = i.get(self.cfg['flag_help'], False) or i.get(self.cfg['flag_help2'], False)
         
-        # Initialized default automation with default database actions
-        if self.default_automation == None:
-           self.default_automation = Automation(self, __file__)
+        # Initialized common automation with collective database actions
+        if self.common_automation == None:
+           self.common_automation = Automation(self, __file__)
 
         # Check automation action
         action = i.get('action','')
@@ -287,15 +180,14 @@ class CM(object):
                 print (self.cfg['info_cli'])
 
                 if cm_help or extra_help:
-                   print_db_actions(self.default_automation)
+                   print_db_actions(self.common_automation)
                    
             return {'return':0, 'warning':'no action'}
 
-
         # Load info about all CM repositories (to enable search for automations and artifacts)
         if self.repos == None:
             repos = Repos(path = self.home_path, cfg = self.cfg, 
-                          path_to_default_repo = self.path_to_cmind_repo)
+                          path_to_internal_repo = self.path_to_cmind_repo)
 
             r = repos.load()
             if r['return'] >0 : return r
@@ -303,15 +195,47 @@ class CM(object):
             # Set only after all initializations
             self.repos = repos
 
-        # Check if forced default automation
-        use_default_automation = True if i.get('default',False) else False
+        # Check if forced common automation
+        use_common_automation = True if i.get('common',False) else False
 
         automation_lst = []
         use_any_action = False
-        
+
+        artifact = i.get('artifact','')
+        artifacts = i.get('artifacts',[]) # Only if more than 1 artifact
+                                          # First element is == artifact
+
+        # Check if automation is "." - then attempt to detect repo, automation and artifact from the current directory
+        if automation == '' or automation == '.':
+            r = self.access({'action':'detect',
+                             'automation':'repo,55c3e27e8a140e48'})
+            if r['return']>0: return r
+
+            # Check and substitute automation
+            if r.get('artifact_found', False):
+                automation = r['cm_automation']
+            else:
+                automation = ''
+
+            # Check and make an artifact (only if artifacts are not specified)
+            if r.get('artifact_found_in_current_path', False) and len(artifacts)==0:
+                artifact = r['cm_artifact']
+
+            if r.get('repo_found',False):
+                cm_repo = r['cm_repo']
+
+                if ':' not in artifact:
+                   artifact = cm_repo + ':' + artifact
+   
+                for ia in len(artifacts):
+                    a = artifacts[ia]
+                    if ':' not in a:
+                        a = cm_repo + ':' + a
+                        artifacts[ia] = a
+
         # If automation!='', attempt to find it and load
-        # Otherwise use the default automation
-        if automation != '' and not use_default_automation:
+        # Otherwise use the common automation
+        if automation != '' and not use_common_automation:
             # Parse automation potentially with a repository
             # and convert it into CM object [(artifact,UID) (,(repo,UID))]
             r = utils.parse_cm_object(automation)
@@ -320,78 +244,83 @@ class CM(object):
             parsed_automation = r['cm_object']
             i['parsed_automation'] = parsed_automation
 
-            # First object in a list is an automation
-            # Second optional object in a list is a repo
-            auto_name = parsed_automation[0] if len(parsed_automation)>0 else ('','')
-            auto_repo = parsed_automation[1] if len(parsed_automation)>1 else None
+            # If wildcards in automation, use the common one (usually for search across different automations)
+            # However, still need above "parse_automation" for proper search
+            if '*' in automation or '?' in automation:
+                use_common_automation = True
+            else:
+                # First object in a list is an automation
+                # Second optional object in a list is a repo
+                auto_name = parsed_automation[0] if len(parsed_automation)>0 else ('','')
+                auto_repo = parsed_automation[1] if len(parsed_automation)>1 else None
 
 
-            # Search for automations in repos (local, default, other) TBD: maybe should be local, other, default?
-            r = self.default_automation.search({'parsed_automation':[('automation','bbeb15d8f0a944a4')],
-                                                'parsed_artifact':parsed_automation})
-            if r['return']>0: return r
-            automation_lst = r['list']
-
-            if len(automation_lst)==1:
-                automation = automation_lst[0]
-                
-                automation_path = automation.path
-                automation_name = self.cfg['default_automation_module_name']
-                automation_meta = automation.meta
-
-                use_any_action = automation_meta.get('use_any_action',False)
-                
-                # Find Python module for this automation
-                try:
-                    found_automation = imp.find_module(automation_name, [automation_path])
-                except ImportError as e:  # pragma: no cover
-                    return {'return': 1, 'error': 'can\'t find Python module code (path={}, name={}, err={})'.format(automation_path, automation_name, format(e))}
-
-                automation_handler = found_automation[0]
-                automation_full_path = found_automation[1]
-
-                # Generate uid for the run-time extension of the loaded Python module
-                # otherwise Python modules with the same extension (key.py for example)
-                # will be reloaded ...
-
-                r = utils.gen_uid()
-                if r['return'] > 0: return r
-                automation_run_time_uid = 'rt-'+r['uid']
-
-                try:
-                   loaded_automation = imp.load_module(automation_run_time_uid, automation_handler, automation_full_path, found_automation[2])
-                except ImportError as e:  # pragma: no cover
-                    return {'return': 1, 'error': 'can\'t load Python module code (path={}, name={}, err={})'.format(automation_path, automation_name, format(e))}
-
-                if automation_handler is not None:
-                    automation_handler.close()
-
-                loaded_automation_class = loaded_automation.CAutomation
-                
-                # Try to load meta description
-                automation_path_meta = os.path.join(automation_path, self.cfg['file_cmeta'])
-
-                r = utils.is_file_json_or_yaml(file_name = automation_path_meta)
+                # Search for automations in repos (local, internal, other) TBD: maybe should be local, other, internal?
+                r = self.common_automation.search({'parsed_automation':[('automation','bbeb15d8f0a944a4')],
+                                                   'parsed_artifact':parsed_automation})
                 if r['return']>0: return r
+                automation_lst = r['list']
 
-                if not r['is_file']:
-                    return {'return':4, 'error':'automation meta not found in {}'.format(automation_path)}
+                if len(automation_lst)==1:
+                    automation = automation_lst[0]
+                    
+                    automation_path = automation.path
+                    automation_name = self.cfg['common_automation_module_name']
+                    automation_meta = automation.meta
 
-                # Load artifact class
-                r=utils.load_yaml_and_json(automation_path_meta)
-                if r['return']>0: return r
+                    use_any_action = automation_meta.get('use_any_action',False)
+                    
+                    # Find Python module for this automation
+                    try:
+                        found_automation = imp.find_module(automation_name, [automation_path])
+                    except ImportError as e:  # pragma: no cover
+                        return {'return': 1, 'error': 'can\'t find Python module code (path={}, name={}, err={})'.format(automation_path, automation_name, format(e))}
 
-                automation_meta = r['meta']
+                    automation_handler = found_automation[0]
+                    automation_full_path = found_automation[1]
 
-            elif len(automation_lst)>1:
-                return {'return':2, 'error':'ambiguity because several automations were found for {}'.format(auto_name)}
+                    # Generate uid for the run-time extension of the loaded Python module
+                    # otherwise Python modules with the same extension (key.py for example)
+                    # will be reloaded ...
 
-            # Report an error if a repo is specified for a given automation action but it's not found there
-            if len(automation_lst)==0 and auto_repo is not None:
-                return {'return':3, 'error':'automation is not found in a specified repo {}'.format(auto_repo)}
+                    r = utils.gen_uid()
+                    if r['return'] > 0: return r
+                    automation_run_time_uid = 'rt-'+r['uid']
+
+                    try:
+                       loaded_automation = imp.load_module(automation_run_time_uid, automation_handler, automation_full_path, found_automation[2])
+                    except ImportError as e:  # pragma: no cover
+                        return {'return': 1, 'error': 'can\'t load Python module code (path={}, name={}, err={})'.format(automation_path, automation_name, format(e))}
+
+                    if automation_handler is not None:
+                        automation_handler.close()
+
+                    loaded_automation_class = loaded_automation.CAutomation
+                    
+                    # Try to load meta description
+                    automation_path_meta = os.path.join(automation_path, self.cfg['file_cmeta'])
+
+                    r = utils.is_file_json_or_yaml(file_name = automation_path_meta)
+                    if r['return']>0: return r
+
+                    if not r['is_file']:
+                        return {'return':4, 'error':'automation meta not found in {}'.format(automation_path)}
+
+                    # Load artifact class
+                    r=utils.load_yaml_and_json(automation_path_meta)
+                    if r['return']>0: return r
+
+                    automation_meta = r['meta']
+
+                elif len(automation_lst)>1:
+                    return {'return':2, 'error':'ambiguity because several automations were found for {}'.format(auto_name)}
+
+                # Report an error if a repo is specified for a given automation action but it's not found there
+                if len(automation_lst)==0 and auto_repo is not None:
+                    return {'return':3, 'error':'automation is not found in a specified repo {}'.format(auto_repo)}
                 
-        # If no automation was found or we force default automation
-        if use_default_automation or len(automation_lst)==0:
+        # If no automation was found or we force common automation
+        if use_common_automation or len(automation_lst)==0:
             auto=('automation','bbeb15d8f0a944a4')
             from . import automation as loaded_automation
 
@@ -427,17 +356,23 @@ class CM(object):
             
             print (self.cfg['info_cli'])
 
-            r = print_db_actions(self.default_automation)
+            r = print_db_actions(self.common_automation)
             if r['return']>0: return r
 
             db_actions = r['db_actions']
 
-            print ('')
-            print ('Automation actions:')
-            print ('')
 
+            actions = []
             for d in sorted(dir(initialized_automation)):
                 if d not in db_actions and type(getattr(initialized_automation, d))==types.MethodType and not d.startswith('_'):
+                    actions.append(d)
+
+            if len(actions)>0:
+                print ('')
+                print ('Automation actions:')
+                print ('')
+
+                for d in actions:
                     print ('* '+d)
 
             return {'return':0, 'warning':'no automation action'}
@@ -473,7 +408,6 @@ class CM(object):
             return {'return':0, 'help':api}
 
         # Process artifacts for this automation action
-        artifacts = i.get('artifacts',[])
         if len(artifacts)>0:
             parsed_artifacts = []
 
@@ -487,7 +421,6 @@ class CM(object):
             i['parsed_artifacts'] = parsed_artifacts
 
         # Check artifact and artifacts
-        artifact = i.get('artifact','')
         if artifact != '':
             # Parse artifact
             r = utils.parse_cm_object(artifact)
