@@ -17,9 +17,13 @@ class CAutomation(Automation):
         """
         Use as wrapper to CK
 
+        Example:
+          cm run ck program:*susan*
+        
         Args:
-           (artifact) (str) - repository name
-           
+          
+
+        
         """
 
         import ck.kernel as ck
