@@ -22,7 +22,7 @@ class CAutomation(Automation):
            (url) (str) - URL of a repository
            (branch) (str) - Git branch
            (checkout) (str) - Git checkout
-           (name) (str) - user-friendly name
+           (desc) (str) - brief repository description (1 line)
            (prefix) (str) - extra directory to keep CM artifacts
            
         """
@@ -31,7 +31,7 @@ class CAutomation(Automation):
 
         alias = i.get('artifact','')
         url = i.get('url','')
-        name = i.get('name','')
+        desc = i.get('desc','')
         prefix = i.get('prefix','')
 
         if url == '':
@@ -72,7 +72,7 @@ class CAutomation(Automation):
         # Prepare path to repo
         repos = self.cmind.repos
 
-        r = repos.pull(alias = alias, url = url, branch = branch, checkout = checkout, console = console, name=name, prefix=prefix)
+        r = repos.pull(alias = alias, url = url, branch = branch, checkout = checkout, console = console, desc=desc, prefix=prefix)
         if r['return']>0: return r
 
         repo_meta = r['meta']
@@ -124,19 +124,20 @@ class CAutomation(Automation):
             for l in lst:
                 meta = l.meta
                 alias = meta.get('alias','')
+                uid = meta.get('uid','')
 
                 if i.get('verbose',False):
 
                    uid = meta['uid']
-                   name = meta.get('name','')
+                   desc = meta.get('desc','')
                    path = repo.path
                    git = meta.get('git',False)
 
-                   print ('{},{} "{}" {}'.format(alias,uid,name,path))
+                   print ('{},{} "{}" {}'.format(alias, uid, desc, path))
                 else:
-                   print ('{} = {}'.format(alias, l.path))
+                   print ('{},{} = {}'.format(alias, uid, l.path))
 
-        return {'return':0, 'lst':lst}
+        return {'return':0, 'list':lst}
 
     ############################################################
     def update(self, i):
@@ -164,7 +165,7 @@ class CAutomation(Automation):
                 r = self.cmind.repos.pull(alias = alias, console = console)
                 if r['return']>0: return r
 
-        return {'return':0, 'lst':self.cmind.repos.lst}
+        return {'return':0, 'list':self.cmind.repos.lst}
 
     ############################################################
     def delete(self, i):
@@ -172,13 +173,17 @@ class CAutomation(Automation):
         Delete repo (just unlink or remove content too)
 
         Args:
-           (artifact) (str) - repository name
+           (artifact) (str) - repository name or UID
            (all) (bool) - if True, remove with content otherwise just unlink
+           (force) (bool) - if True, quiet mode
+           (f) (bool) - if True, quiet mode
            
         """
 
         console = i.get('out') == 'con'
 
+        force = (i.get('force',False) or i.get('f',False))
+        
         # Search CM repository
         i['action']='search'
         i['out']=None
@@ -186,13 +191,13 @@ class CAutomation(Automation):
         
         if r['return'] >0 : return r
 
-        lst = r['lst']
+        lst = r['list']
         if len(lst)==0:
            return {'return':1, 'error':'Repository not found'}
 
         remove_all = i.get('all', '')
 
-        r = self.cmind.repos.delete(lst, remove_all = remove_all, console = console)
+        r = self.cmind.repos.delete(lst, remove_all = remove_all, console = console, force = force)
 
         return r
 
@@ -202,30 +207,76 @@ class CAutomation(Automation):
         Initialize repo
 
         Args:
-           (artifact) (str) - repository name
+           (artifact) (str) - repository name or UID
            (uid) (str) - initialize CM repository with a given UID
            (path) (str) - initalize CM repository in a given local path
-           (name) (str) - brief description of this CM repository
+           (desc) (str) - brief description of this CM repository
            (prefix) (str) - extra directory to keep CM artifacts
         """
 
         console = i.get('out') == 'con'
 
         alias = i.get('artifact', '')
+        uid = i.get('uid','')
         path = i.get('path', '')
-        name = i.get('name','')
+        desc = i.get('desc','')
         prefix = i.get('prefix','')
 
         # If path is not specified, initialize in the current directory!
         if (path=='' and alias=='') or (alias!='' and path=='.'):
            path = os.path.abspath(os.getcwd())
-
-           if alias == '':
-              # Try to get the name of the directory
-              alias = os.path.basename(path).strip()
         
+        # Check if there is a repo in a path
+        r = self.cmind.access({'action':'detect',
+                               'automation':self.meta['alias']+','+self.meta['uid'],
+                               'path':path})
+        if r['return']>0: return r
+
+        repo_desc_found = r['found']
+        repo_registered = r.get('registered',False)
+        
+        if repo_desc_found:
+            if repo_registered:
+                return {'return':1, 'error':'CM repository found in this path and already registered in CM'}
+            
+            if console:
+                print ('CM repository description found in this path: {}'.format(r['path_to_repo_desc']))
+
+            path= r['path_to_repo']
+            
+            repo_meta = r['meta']
+
+            repo_meta_alias = repo_meta.get('alias','')
+            repo_meta_uid = repo_meta.get('uid','')
+            repo_meta_prefix = repo_meta.get('prefix','')
+
+            # Check if mismatch in alias
+            if alias!='':
+                if repo_meta_alias!='' and repo_meta_alias!=alias:
+                    return {'return':1, 'error':'mismatch between new repo alias and the existing one'}
+            else:
+                alias = repo_meta_alias
+
+            # Check if mismatch in UID
+            if uid!='':
+                if repo_meta_uid!='' and repo_meta_uid!=uid:
+                    return {'return':1, 'error':'mismatch between new repo UID and the existing one'}
+            else:
+                uid = repo_meta_uid
+
+            # Check if mismatch in prefix
+            if prefix!='':
+                if repo_meta_prefix!='' and repo_meta_prefix is not None and repo_meta_prefix!=prefix:
+                    return {'return':1, 'error':'mismatch between new repo prefix and the existing one'}
+            else:
+                prefix = repo_meta_prefix
+
+        # If still no alias, use from the path
+        if alias == '':
+            # Try to get the name of the directory
+            alias = os.path.basename(path).strip().lower()
+
         # Generate UID
-        uid = i.get('uid','')
         if uid =='':
             r=utils.gen_uid()
             if r['return']>0: return r
@@ -237,7 +288,7 @@ class CAutomation(Automation):
             print (self.cmind.cfg['line'])
             print ('Alias:    {}'.format(alias))
             print ('UID:      {}'.format(uid))
-            print ('Name:     {}'.format(name))
+            print ('Desc:     {}'.format(desc))
             print ('Prefix:   {}'.format(prefix))
             print ('')
         
@@ -248,13 +299,13 @@ class CAutomation(Automation):
             r=self.cmind.access(ii) 
             if r['return']>0: return r
 
-            lst=r['lst']
+            lst=r['list']
 
             if len(lst)>0: 
                 return {'return':1, 'error':'Repository "{}" is already registered in CM'.format(repo_artifact)}
 
         # Create repository 
-        r = self.cmind.repos.init(alias = alias, uid = uid, path = path, console = console, name=name, prefix=prefix)
+        r = self.cmind.repos.init(alias = alias, uid = uid, path = path, console = console, desc=desc, prefix=prefix, only_register=repo_desc_found)
         return r
 
     ############################################################
@@ -265,7 +316,7 @@ class CAutomation(Automation):
         Args:
            (artifact) (str) - repository name
            (path) (str) - if !='' use this non-standard path
-           (name) (str) - user-friendly name
+           (desc) (str) - brief repository description
            (prefix) (str) - extra directory to keep CM artifacts
         """
 
@@ -277,7 +328,7 @@ class CAutomation(Automation):
         Pack repo for further distribution
 
         Args:
-           (artifact) (str) - repository name
+           (artifact) (str) - repository name or UID
         """
 
         import zipfile
@@ -290,7 +341,7 @@ class CAutomation(Automation):
 
         if r['return']>0: return r
 
-        lst = r['lst']
+        lst = r['list']
 
         if len(lst)==0:
             return {'return':16, 'error':'no repsitories found'}
@@ -375,14 +426,14 @@ class CAutomation(Automation):
         # Get meta info
         uid = repo_meta['uid']
         alias = repo_meta['alias']
-        name = repo_meta.get('name','')
+        desc = repo_meta.get('desc','')
         prefix = repo_meta.get('prefix','')
 
         # Check if repo exists
         r = self.search({'parsed_artifact':[(alias,uid)]})
         if r['return']>0: return r
 
-        lst = r['lst']
+        lst = r['list']
 
         if len(lst)>0:
             return {'return':1, 'error':'Repository already exists'}
@@ -400,7 +451,7 @@ class CAutomation(Automation):
 
         # Unpacking zip
         for f in files:
-            if not f.startswith('.') and not f.startswith('/') and not f.startswith('\\'):
+            if not f.startswith('..') and not f.startswith('/') and not f.startswith('\\'):
                 file_path = os.path.join(repo_path, f)
                 if f.endswith('/'):
                     # create directory
@@ -422,7 +473,7 @@ class CAutomation(Automation):
         return r_new
 
     ##############################################################################
-    def convert_ck_to_cm(self, i):
+    def import_ck_to_cm(self, i):
         """
         Convert CK repos to CM repos
         
@@ -467,65 +518,263 @@ class CAutomation(Automation):
                                 'path':rpath})
                 if r['return']>0: return r
 
-                dir1 = os.listdir(rpath)
-
-                for d1 in dir1:
-                    if d1!='.cm':
-                        dd1=os.path.join(rpath, d1)
-                        if os.path.isdir(dd1):
-
-                            dir2 = os.listdir(dd1)
-
-                            for d2 in dir2:
-                                if d2!='.cm':
-                                    dd2=os.path.join(dd1, d2, '.cm')
-                                    if os.path.isdir(dd2):
-                                        dmeta = {}
-                                        
-                                        broken = False
-                                        for f in ['info.json','meta.json']:
-                                            dd2a=os.path.join(dd2, f)
-
-                                            if os.path.isfile(dd2a):
-                                                
-                                                r=ck.load_json_file({'json_file':dd2a})
-                                                if r['return']>0: return r
-
-                                                dmeta.update(r['dict'])
-                                            else:
-                                                broken=True
-                                                break
-
-                                        if broken or \
-                                           'backup_data_uid' not in dmeta or \
-                                           'backup_module_uid' not in dmeta or \
-                                           'backup_module_uoa' not in dmeta:
-
-                                           print ('Ignored: '+dd2)
-                                        else:
-                                           backup_data_uid = dmeta['backup_data_uid']
-
-                                           backup_module_uid = dmeta['backup_module_uid']
-                                           backup_module_uoa = dmeta['backup_module_uoa']
-                                        
-                                           dmeta2 = {}
-                                           for k in dmeta:
-                                               if not k.startswith('backup_') and not k.startswith('cm_'):
-                                                   dmeta2[k]=dmeta[k]
-
-                                           dmeta2['uid']=backup_data_uid
-
-                                           if not ck.is_uid(d2):
-                                              dmeta2['alias']=d2
-
-                                           dmeta2['automation_alias']=backup_module_uoa
-                                           dmeta2['automation_uid']=backup_module_uid
-
-                                           cm_meta_file = os.path.join(dd1, d2, '_cm.json')
-
-                                           print (cm_meta_file)
-
-                                           r=ck.save_json_to_file({'json_file':cm_meta_file, 'dict': dmeta2, 'sort_keys':'yes'})
-                                           if r['return']>0: return r
+                r = convert_ck_dir_to_cm(rpath)
+                if r['return']>0: return r
 
         return {'return':0}
+
+    ##############################################################################
+    def convert_ck_to_cm(self, i):
+        """
+        Convert CM repo in the CK format to CM format
+        
+        Input:  {
+                  (artifact)
+                }
+
+        Output: {
+                  return       - return code =  0, if successful
+                                             >  0, if error
+                  (error)      - error text if return > 0
+                }
+
+        """
+
+        import ck.kernel as ck
+        import cmind
+        import os
+
+
+        console = i.get('out') == 'con'
+
+        # Search CM repository
+        i['action']='search'
+        i['out']=None
+        r=self.cmind.access(i)
+        
+        if r['return'] >0 : return r
+
+        lst = r['list']
+        if len(lst)==0:
+           return {'return':1, 'error':'Repository not found'}
+
+        for repo in lst:
+
+            ralias = repo.meta['alias']
+            ruid = repo.meta['uid']
+            rpath = repo.path
+
+            if rpath!='' and os.path.isdir(rpath):
+                print ('********************************************************')
+                print (ralias)
+                print (ruid)
+                print (rpath)
+
+                r = convert_ck_dir_to_cm(rpath)
+                if r['return']>0: return r
+
+        return {'return':0}
+
+
+    ############################################################
+    def detect(self, i):
+        """
+        Detect repo in the current path
+
+        Args:
+          (path) (str) - path to repo (otherwise use current path)
+        
+
+        """
+
+        console = i.get('out') == 'con'
+
+        # Prepare path to repo
+        repos = self.cmind.repos
+
+        path = i.get('path')
+        if path == '': path = None
+        
+        # Search for cmr.yaml or cmr.json in current directory and above
+        r=utils.find_file_in_current_directory_or_above([self.cmind.cfg['file_meta_repo']+'.json', 
+                                                         self.cmind.cfg['file_meta_repo']+'.yaml'],
+                                                         path_to_start = path)
+        if r['return']>0: return r
+
+        rr = {'return':0}
+        
+        found = r['found']
+        rr['found'] = found
+
+        registered = False
+
+        if found:
+            path_to_repo_desc = r['path_to_file']
+            path_to_repo = r['path']
+
+            rr['path_to_repo_desc'] = path_to_repo_desc
+            rr['path_to_repo'] = path_to_repo
+
+            rr['found_in_current_path'] = r['found_in_current_path']
+
+            # Load meta
+            r = utils.load_json_or_yaml(file_name = path_to_repo_desc)
+            if r['return']>0: return r
+
+            repo_meta = r['meta']
+
+            rr['meta'] = repo_meta
+
+            # Check if belongs to installed repo already
+            for tmp_path in repos.paths:
+                if tmp_path == path_to_repo:
+                    registered = True
+
+            if registered:
+                rr['cm_repo'] = utils.assemble_cm_object(repo_meta['alias'],repo_meta['uid'])
+                
+        rr['registered'] = registered
+
+        # Search for _cm.yaml or _cm.json in current directory and below
+        r=utils.find_file_in_current_directory_or_above([self.cmind.cfg['file_cmeta']+'.json', 
+                                                         self.cmind.cfg['file_cmeta']+'.yaml'],
+                                                         path_to_start = path,
+                                                         reverse = True)
+        if r['return']>0: return r
+
+        artifact_found = r['found']
+        artifact_found_in_current_path = r.get('found_in_current_path', False)
+
+        rr['artifact_found'] = artifact_found
+
+        if artifact_found:
+            path_to_artifact_desc = r['path_to_file']
+            path_to_artifact = r['path']
+
+            rr['path_to_artifact_desc'] = path_to_artifact_desc
+            rr['path_to_artifact'] = path_to_artifact
+
+            rr['artifact_found_in_current_path'] = artifact_found_in_current_path
+
+            # Load meta
+            r = utils.load_json_or_yaml(file_name = path_to_artifact_desc)
+            if r['return']>0: return r
+
+            artifact_meta = r['meta']
+
+            rr['artifact_meta'] = artifact_meta
+
+            rr['cm_automation'] = utils.assemble_cm_object(artifact_meta['automation_alias'],artifact_meta['automation_uid'])
+
+            if artifact_found_in_current_path:
+                rr['cm_artifact'] = utils.assemble_cm_object(artifact_meta['alias'],artifact_meta['uid'])
+
+        # Print
+        if console:
+            if not found:
+                print ('CM repository not found')
+            else:
+                print ('CM repository found:')
+
+                print ('')
+                print ('Path to repo desc file: {}'.format(path_to_repo_desc))
+                print ('Path to repo:           {}'.format(path_to_repo))
+
+                if registered:
+                    print ('')
+                    print ('  This repository is registered in CM')
+                    
+                    print ('')
+                    print ('  Repo alias: {}'.format(repo_meta['alias']))
+                    print ('  Repo UID:   {}'.format(repo_meta['uid']))
+
+                if artifact_found:
+                    print ('')
+                    print ('Current directory has related CM automation:')
+                    
+                    print ('')
+                    print ('  Automation alias: {}'.format(artifact_meta['automation_alias']))
+                    print ('  Automation UID:   {}'.format(artifact_meta['automation_uid']))
+
+                if artifact_found_in_current_path:
+                    print ('')
+                    print ('Current directory has a CM artifact:')
+                    
+                    print ('')
+                    print ('  Artifact alias: {}'.format(artifact_meta['alias']))
+                    print ('  Artifact UID:   {}'.format(artifact_meta['uid']))
+
+        return rr
+
+
+
+##############################################################################
+def convert_ck_dir_to_cm(rpath):
+    """
+    """
+
+    import ck.kernel as ck
+    import os
+
+    dir1 = os.listdir(rpath)
+
+    for d1 in dir1:
+        if d1!='.cm':
+            dd1=os.path.join(rpath, d1)
+            if os.path.isdir(dd1):
+
+                dir2 = os.listdir(dd1)
+
+                for d2 in dir2:
+                    if d2!='.cm':
+                        dd2=os.path.join(dd1, d2, '.cm')
+                        if os.path.isdir(dd2):
+                            dmeta = {}
+                            
+                            broken = False
+                            for f in ['info.json','meta.json']:
+                                dd2a=os.path.join(dd2, f)
+
+                                if os.path.isfile(dd2a):
+                                    
+                                    r=ck.load_json_file({'json_file':dd2a})
+                                    if r['return']>0: return r
+
+                                    dmeta.update(r['dict'])
+                                else:
+                                    broken=True
+                                    break
+
+                            if broken or \
+                               'backup_data_uid' not in dmeta or \
+                               'backup_module_uid' not in dmeta or \
+                               'backup_module_uoa' not in dmeta:
+
+                               print ('Ignored: '+dd2)
+                            else:
+                               backup_data_uid = dmeta['backup_data_uid']
+
+                               backup_module_uid = dmeta['backup_module_uid']
+                               backup_module_uoa = dmeta['backup_module_uoa']
+                            
+                               dmeta2 = {}
+                               for k in dmeta:
+                                   if not k.startswith('backup_') and not k.startswith('cm_'):
+                                       dmeta2[k]=dmeta[k]
+
+                               dmeta2['uid']=backup_data_uid
+
+                               if not ck.is_uid(d2):
+                                  dmeta2['alias']=d2
+
+                               dmeta2['automation_alias']=backup_module_uoa
+                               dmeta2['automation_uid']=backup_module_uid
+
+                               cm_meta_file = os.path.join(dd1, d2, '_cm.json')
+
+                               print (cm_meta_file)
+
+                               r=ck.save_json_to_file({'json_file':cm_meta_file, 'dict': dmeta2, 'sort_keys':'yes'})
+                               if r['return']>0: return r
+
+    return {'return':0}
