@@ -426,7 +426,10 @@ def match_objects(uid, alias, uid2, alias2):
     if alias is None: alias = ''
     if uid2 is None: uid2 = ''
     if alias2 is None: alias2 = ''
-    
+
+    uid = uid.lower()
+    uid2 = uid2.lower()
+
     # We match first by UID no matter what the alias is (the last one can change)
     if uid!='' and uid2!='':
         if uid==uid2:
@@ -438,13 +441,16 @@ def match_objects(uid, alias, uid2, alias2):
         if '*' in alias2 or '?' in alias2:
             object2_has_wildcards = True
 
+        alias = alias.lower()
+        alias2 = alias2.lower()
+        
         if object2_has_wildcards:
             import fnmatch
 
             if fnmatch.fnmatch(alias, alias2):
                 match = True
         else:
-            if alias2=='' or alias.lower()==alias2.lower():
+            if alias2=='' or alias==alias2:
                 match = True
 
     return {'return':0, 'match': match}
@@ -605,7 +611,7 @@ def find_api(file_name, func):
 
     Args:
               file_name (str): Python module
-              fund (str): func name
+              func (str): func name
 
     Returns:
               (dict): Unified CK dictionary:
@@ -644,3 +650,124 @@ def find_api(file_name, func):
     api = string[line1+1:line_comment2+3]
     
     return {'return':0, 'api':api}
+
+
+###########################################################################
+def find_file_in_current_directory_or_above(file_names, path_to_start = None, reverse = False):
+    """Find file in the current directory or above
+
+    Args:
+              file_names (list): files to find
+              path_to_start (str): path to start
+                                   use current directory if None
+
+    Returns:
+              (dict): Unified CK dictionary:
+
+                return (int): return code =  0, if successful
+                                          >  0, if error
+                (error) (str): error text if return > 0
+
+                found (bool): True if found
+
+                path_to_file (str): full path to found file
+                path (str): path where found file is
+
+    """
+
+    if path_to_start is None:
+        path_to_start=os.getcwd()
+    
+    found = False
+
+    current_path = path_to_start
+
+    # Only makes sense if found
+    found_in_current_path = True
+
+    # Go backwards to find cmr.yaml or cmr.json (CM repo description)
+    while True:
+       for file_name in file_names:
+           path_to_file = os.path.join(current_path, file_name)
+
+           if os.path.isfile(path_to_file):
+               found = True
+               break
+
+       if found:
+           break
+       
+       if reverse:
+          # Get first directory
+          dirs = os.listdir(current_path)
+
+          new_path = ''
+
+          for d in dirs:
+              if not d.startswith('.'):
+                  test_dir = os.path.join(current_path, d)
+                  if os.path.isdir(test_dir):
+                      new_path = test_dir
+                      break
+
+          if new_path == '':
+              break        
+
+       else:
+          new_path = os.path.dirname(current_path)
+
+          if new_path == current_path:
+              break
+
+       found_in_current_path = False
+
+       current_path = new_path
+
+    r = {'return':0, 'found': found}
+
+    if found:
+        r['path_to_file'] = path_to_file
+        r['path'] = os.path.dirname(path_to_file)
+
+        r['found_in_current_path'] = found_in_current_path
+
+    return r
+
+###########################################################################
+def assemble_cm_object(alias,uid):
+    """Assemble CM object
+
+    Args:
+              file_names (list): files to find
+              path_to_start (str): path to start
+                                   use current directory if None
+
+    Returns:
+              (str): CM object
+
+                return (int): return code =  0, if successful
+                                          >  0, if error
+                (error) (str): error text if return > 0
+
+                found (bool): True if found
+
+                path_to_file (str): full path to found file
+                path (str): path where found file is
+
+    """
+
+    if alias == None: alias = ''
+    if uid == None: uid = ''
+
+    cm_obj = ''
+
+    if uid != '':
+       cm_obj = uid
+
+    if alias != '':
+       if cm_obj !='':
+           cm_obj = alias + ',' + cm_obj
+       else:
+           cm_obj = alias
+
+    return cm_obj
